@@ -2229,7 +2229,7 @@ sub _write_minimal_metadata {
 name: $p->{dist_name}
 version: $p->{dist_version}
 author:
-@{[ join "\n", map "  - $_", @{$self->dist_author} ]}
+@{[ join "\n", map "  - $_", @{$self->dist_author || []} ]}
 abstract: @{[ $self->dist_abstract ]}
 license: $p->{license}
 generated_by: Module::Build version $Module::Build::VERSION, without YAML.pm
@@ -2274,6 +2274,7 @@ EOM
   }
 
   require YAML;
+  require YAML::Node;
 
   # We use YAML::Node to get the order nice in the YAML file.
   my $node = YAML::Node->new({});
@@ -2488,7 +2489,7 @@ sub have_c_compiler {
   
   print "Checking if compiler tools configured... " if $p->{verbose};
   
-  my $c_file = $self->config_file('compilet.c');
+  my $c_file = File::Spec->catfile(File::Spec->tmpdir, 'compilet.c');
   {
     my $fh = IO::File->new("> $c_file") or die "Can't create $c_file: $!";
     print $fh "int boot_compilet() { return 1; }\n";
